@@ -19,12 +19,14 @@
  */
 class DiagnosticStyle : public QProxyStyle
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     typedef QProxyStyle BaseStyle;
-    void drawControl(ControlElement element, const QStyleOption* option, QPainter* painter, const QWidget* widget) const override;
-    ~DiagnosticStyle() override { }
+    void drawControl(ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const override;
+    ~DiagnosticStyle() override
+    {
+    }
 };
 
 #endif // KTECHLAB_CORE_MAIN_H__
