@@ -22,34 +22,37 @@
 class EC555 : public Component
 {
 public:
-	EC555( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
-	~EC555() override;
-	
-	static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
-	static LibraryItem *libraryItem();
-	
-	void stepNonLogic() override;
-	bool doesStepNonLogic() const override { return true; }
+    EC555(ICNDocument *icnDocument, bool newItem, const char *id = nullptr);
+    ~EC555() override;
+
+    static Item *construct(ItemDocument *itemDocument, bool newItem, const char *id);
+    static LibraryItem *libraryItem();
+
+    void stepNonLogic() override;
+    bool doesStepNonLogic() const override
+    {
+        return true;
+    }
 
 private:
-	Pin * ground;
-	Pin * trigger;
-	Pin * output;
-	Pin * reset;
-	Pin * control;
-	Pin * threshold;
-	Pin * discharge;
-	Pin * vcc;
+    Pin *ground;
+    Pin *trigger;
+    Pin *output;
+    Pin *reset;
+    Pin *control;
+    Pin *threshold;
+    Pin *discharge;
+    Pin *vcc;
 
-	Resistance *m_r1;
-	Resistance *m_r23;
-	Resistance *m_po_sink;
-	Resistance *m_po_source;
-	Resistance *m_r_discharge;
+    Resistance *m_r1;
+    Resistance *m_r23;
+    Resistance *m_po_sink;
+    Resistance *m_po_source;
+    Resistance *m_r_discharge;
 
-	bool old_com1;
-	bool old_com2;
-	bool old_q;
+    bool old_com1;
+    bool old_com2;
+    bool old_q;
 };
 
 #endif
