@@ -11,8 +11,8 @@
 #ifndef CURRENTSIGNAL_H
 #define CURRENTSIGNAL_H
 
-#include "reactive.h"
 #include "elementsignal.h"
+#include "reactive.h"
 
 /**
 @short CurrentSignal
@@ -21,23 +21,29 @@
 class CurrentSignal : public Reactive, public ElementSignal
 {
 public:
-	CurrentSignal(  double delta, double current );
-	~CurrentSignal() override;
-	
-	Element::Type type() const override { return Element_CurrentSignal; }
-	void setCurrent( double current );
-	double current() { return m_current; }
-	void time_step() override;
+    CurrentSignal(double delta, double current);
+    ~CurrentSignal() override;
+
+    Element::Type type() const override
+    {
+        return Element_CurrentSignal;
+    }
+    void setCurrent(double current);
+    double current()
+    {
+        return m_current;
+    }
+    void time_step() override;
 
 protected:
-	void updateCurrents() override;
-	void add_initial_dc() override;
+    void updateCurrents() override;
+    void add_initial_dc() override;
 
-	void addCurrents();
+    void addCurrents();
 
-	double m_current; // Current
-	double m_oldCurrent; // Old calculated current
-	double m_newCurrent; // New calculated current
+    double m_current;    // Current
+    double m_oldCurrent; // Old calculated current
+    double m_newCurrent; // New calculated current
 };
 
 #endif
