@@ -18,27 +18,21 @@
 class ElementSignal
 {
 public:
-	enum Type
-	{
-		st_sinusoidal,
-		st_square,
-		st_sawtooth,
-		st_triangular
-	};
-	ElementSignal();
-	~ElementSignal();
-	
-	void setStep(Type type, double frequency );
-	/**
-	 * Advances the timer, returns amplitude (between -1 and 1)
-	 */
-	double advance(double delta);
+    enum Type { st_sinusoidal, st_square, st_sawtooth, st_triangular };
+    ElementSignal();
+    ~ElementSignal();
+
+    void setStep(Type type, double frequency);
+    /**
+     * Advances the timer, returns amplitude (between -1 and 1)
+     */
+    double advance(double delta);
 
 protected:
-	Type m_type;
-	double m_time;
-	double m_frequency;
-	double m_omega; // Used for sinusoidal signal
+    Type m_type;
+    double m_time;
+    double m_frequency;
+    double m_omega; // Used for sinusoidal signal
 };
 
 #endif
