@@ -10,41 +10,34 @@
 
 #include "end.h"
 
-#include "libraryitem.h"
 #include "flowcode.h"
+#include "libraryitem.h"
 
 #include <KLocalizedString>
 
-Item* End::construct( ItemDocument *itemDocument, bool newItem, const char *id )
+Item *End::construct(ItemDocument *itemDocument, bool newItem, const char *id)
 {
-	return new End( (ICNDocument*)itemDocument, newItem, id );
+    return new End((ICNDocument *)itemDocument, newItem, id);
 }
 
-LibraryItem* End::libraryItem()
+LibraryItem *End::libraryItem()
 {
-	return new LibraryItem(
-		QStringList(QString("flow/end")),
-		i18n("End"),
-		i18n("Common"),
-		"end.png",
-		LibraryItem::lit_flowpart,
-		End::construct );
+    return new LibraryItem(QStringList(QString("flow/end")), i18n("End"), i18n("Common"), "end.png", LibraryItem::lit_flowpart, End::construct);
 }
 
-End::End( ICNDocument *icnDocument, bool newItem, const char *id )
-	: FlowPart( icnDocument, newItem, id ? id : "END" )
+End::End(ICNDocument *icnDocument, bool newItem, const char *id)
+    : FlowPart(icnDocument, newItem, id ? id : "END")
 {
-	m_name = i18n("End");
-	initRoundedRectSymbol();
-	createStdInput();
-	setCaption( i18n("End") );
+    m_name = i18n("End");
+    initRoundedRectSymbol();
+    createStdInput();
+    setCaption(i18n("End"));
 }
 
 End::~End()
 {
 }
 
-void End::generateMicrobe( FlowCode */*code*/ )
+void End::generateMicrobe(FlowCode * /*code*/)
 {
 }
-
