@@ -1,7 +1,7 @@
 //
 // C++ Implementation: flowconnector
 //
-// Description: 
+// Description:
 //
 //
 // Author: David Saxton, Alan Grimes, Zoltan Padrah <zoltan.padrah@gmail.com>, (C) 2008
@@ -13,28 +13,26 @@
 
 #include "fpnode.h"
 
-FlowConnector::FlowConnector(FPNode* startNode, FPNode* endNode, ICNDocument* _ICNDocument, QString* id): Connector(startNode, endNode, _ICNDocument, id)
+FlowConnector::FlowConnector(FPNode *startNode, FPNode *endNode, ICNDocument *_ICNDocument, QString *id)
+    : Connector(startNode, endNode, _ICNDocument, id)
 {
-	m_startFpNode = startNode;
-	m_endFpNode = endNode;
+    m_startFpNode = startNode;
+    m_endFpNode = endNode;
 }
 
-
 FlowConnector::~FlowConnector()
 {
 }
 
-Node *FlowConnector::startNode() const {
+Node *FlowConnector::startNode() const
+{
     FPNode *fpNode = m_startFpNode;
-    Node *node = dynamic_cast<Node*> (fpNode);
+    Node *node = dynamic_cast<Node *>(fpNode);
     return node;
     // return static_cast<Node*> ( static_cast<FPNode*> (m_startFpNode) );
-
 }
 
-Node *FlowConnector::endNode() const {
+Node *FlowConnector::endNode() const
+{
     return m_endFpNode;
-
 }
-
-
