@@ -11,33 +11,33 @@
 #ifndef ICNVIEW_H
 #define ICNVIEW_H
 
-#include <itemview.h>
-#include <icndocument.h>
 #include <KToolBarPopupAction>
+#include <icndocument.h>
+#include <itemview.h>
 
 /**
 @author David Saxton
 */
 class ICNView : public ItemView
 {
-	Q_OBJECT
-	public:
-		ICNView( ICNDocument * icnDocument, ViewContainer *viewContainer, uint viewAreaId, const char * name = nullptr );
-		~ICNView() override;
-		
-	protected slots:
-		void slotSetRoutingMode( QAction* action ); // 0 = auto, 1 = manual
-		void slotSetRoutingAuto();
-		void slotSetRoutingManual();
-		void slotUpdateRoutingMode( bool manualRouting );
-		void slotUpdateRoutingToggles( bool manualRouting );
+    Q_OBJECT
+public:
+    ICNView(ICNDocument *icnDocument, ViewContainer *viewContainer, uint viewAreaId);
+    ~ICNView() override;
 
-	protected:
-		KToolBarPopupAction * m_pRoutingModeToolbarPopup;
-		QAction * m_pManualRoutingAction;
-		QAction * m_pAutoRoutingAction;
-        QAction *m_actMenuRouteAutoRoute;
-        QAction *m_actMenuRouteManRoute;
+protected slots:
+    void slotSetRoutingMode(QAction *action); // 0 = auto, 1 = manual
+    void slotSetRoutingAuto();
+    void slotSetRoutingManual();
+    void slotUpdateRoutingMode(bool manualRouting);
+    void slotUpdateRoutingToggles(bool manualRouting);
+
+protected:
+    KToolBarPopupAction *m_pRoutingModeToolbarPopup;
+    QAction *m_pManualRoutingAction;
+    QAction *m_pAutoRoutingAction;
+    QAction *m_actMenuRouteAutoRoute;
+    QAction *m_actMenuRouteManRoute;
 };
 
 #endif
