@@ -21,7 +21,6 @@
  */
 
 #include "../src/ktechlab.h"
-#include "config.h"
 
 #include <KAboutData>
 #include <KLocalizedString>
@@ -29,11 +28,13 @@
 #include <QApplication>
 #include <QCommandLineParser>
 
+#include <ktechlab_version.h>
+#include <ktechlab_debug.h>
 
 int main(int argc, char *argv[]) {
     QApplication app(argc, argv);
     KAboutData aboutData(QByteArray("ktechlab"), i18n("KTechLab"),
-                VERSION, i18n("An IDE for microcontrollers and electronics"),
+                KTECHLAB_VERSION_STRING, i18n("An IDE for microcontrollers and electronics"),
                 KAboutLicense::GPL_V2, i18n("(C) 2003-2017, The KTechLab developers"),
                 "", "https://userbase.kde.org/KTechlab", "ktechlab-devel@kde.org" );
     KAboutData::setApplicationData(aboutData);
@@ -44,4 +45,5 @@ int main(int argc, char *argv[]) {
     aboutData.processCommandLine(&parser);
 
     KTechlab *ktechlab = new KTechlab();
+    qCInfo(KTL_LOG) << "ktechlab instance:" << ktechlab;
 }
